@@ -3,6 +3,7 @@ from __future__ import print_function
 
 import getpass
 import os
+import re
 import socket
 import sysconfig
 import sys
@@ -35,6 +36,9 @@ DYNAMIC_MODULE_PREFIX = sys.intern('__dynamic_modules__')
 # On non-macOS platforms this may be awry:
 ENCODING = sys.intern(sys.getfilesystemencoding().upper()) # 'UTF-8'
 
+# The environment-variable name partition separator:
+ENVIRONS_SEP = sys.intern('_')
+
 # Possible names for file arguments (used for introspection):
 FILE_ARGUMENT_NAMES = ('path', 'pth', 'file')
 
@@ -51,6 +55,9 @@ lam = lambda: None
 MAXINT = getattr(sys, 'maxint',
          getattr(sys, 'maxsize', (2 ** 64) / 2))
 
+# The namespace separator for namespaced KeyMaps:
+NAMESPACE_SEP = sys.intern(':')
+
 # The PATH environment variable, with a sensible default:
 PYTHON_BIN = os.path.join(sysconfig.get_path('data'), 'bin')
 DEFAULT_PATH = os.pathsep.join(filter(os.path.exists, (PYTHON_BIN,
@@ -87,6 +94,9 @@ NotImplementedType = type(NotImplemented)
 
 SINGLETON_TYPES = (bool, NoneType, EllipsisType, NotImplementedType)
 
+# String used in custom repr implementations:
+STRINGPAIR = sys.intern("{!s} : {!s}")
+
 # Path to the script directory:
 SCRIPT_PATH = sys.intern(os.path.join(BASEPATH, 'clu', 'scripts'))
 
@@ -116,6 +126,9 @@ VERBOTEN = pytuple('all', 'cached', 'loader', 'file', 'spec')
 VERBOTEN += BUILTINS
 VERBOTEN += ('Namespace', 'SimpleNamespace')
 
+# Regex for picking up whitespace:
+WHITESPACE = re.compile(r'\s+')
+
 # XDG_RUNTIME_DIR support:
 basedir = "/usr/local/var/run/xdg"
 symlink = os.path.join(basedir, 'CURRENT')
@@ -142,10 +155,12 @@ __all__ = ('BASEPATH',
            'DEFAULT_TERMINAL_WIDTH',
            'DYNAMIC_MODULE_PREFIX',
            'ENCODING',
+           'ENVIRONS_SEP',
            'FILE_ARGUMENT_NAMES',
            'HOSTNAME',
            'LAMBDA', 'λ',
            'MAXINT',
+           'NAMESPACE_SEP',
            'PATH',
            'PARTIAL', 'φ',
            'PROJECT_NAME', 'PROJECT_PATH',
@@ -154,11 +169,13 @@ __all__ = ('BASEPATH',
            'QUALIFIER',
            'SEPARATOR_WIDTH',
            'SINGLETON_TYPES',
+           'STRINGPAIR',
            'SCRIPT_PATH', 'TEST_PATH',
            'TEXTMATE',
            'TOKEN',
            'USER',
            'VERBOTEN',
+           'WHITESPACE',
            'XDG_RUNTIME_BASE', 'XDG_RUNTIME_DIR',
                                'XDG_RUNTIME_MODE',
            'pytuple', 'NoDefault')
