@@ -8,10 +8,9 @@ iterchain = chain.from_iterable
 import clu.abstract
 import collections
 import collections.abc
-import re
 import sys
 
-from clu.constants.consts import NoDefault
+from clu.constants.consts import STRINGPAIR, WHITESPACE, NoDefault
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -87,9 +86,6 @@ class OrderedValuesView(collections.abc.ValuesView,
 
 # CHAINMAP: custom reprlib.Repr subclass
 
-WHITESPACE = re.compile(r'\s+')
-STRINGPAIR = "{!s} : {!s}"
-
 typename = lambda thing: type(thing).__name__
 
 @export
@@ -134,7 +130,8 @@ class ChainRepr(Repr):
             key = tuple(mapping.keys())[0]
             item = STRINGPAIR.format(key, self.subrepr(mapping[key], level))
             return f"{{ {item} }}"
-        items = (STRINGPAIR.format(key, self.subrepr(mapping[key], level)) for key in mapping.keys())
+        items = (STRINGPAIR.format(key, self.subrepr(mapping[key], level)) \
+                               for key in mapping.keys())
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
@@ -147,24 +144,35 @@ class ChainRepr(Repr):
             sub-repr method calls accordingly.
         """
         from clu.naming import qualified_name
-        from clu.typology import iterlen
         from clu.testing.utils import multiple
         
         tn = typename(chainmap)
-        mapcount = iterlen(chainmap.mapchain())
+        mapcount = len(chainmap.maps)
         keycount = len(chainmap.keys())
-        items = (STRINGPAIR.format(qualified_name(type(mapping)), self.primerepr(mapping, level - 1)) for mapping in chainmap.mapchain())
+        items = (STRINGPAIR.format(qualified_name(type(mapping)),
+                                   self.primerepr(mapping, level - 1)) \
+                                   for mapping in chainmap.maps)
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
-        return f"{tn} «{mapcount} map{multiple(mapcount)}, {keycount} key{multiple(keycount)}» [\n{ts}{total}\n{ls}]"
+        return f"{tn} «{mapcount} map{multiple(mapcount)}, " \
+                     f"{keycount} key{multiple(keycount)}» " \
+                     f"[\n{ts}{total}\n{ls}]"
     
     def repr_ChainMap(self, chainmap, level):
         # Handles both “clu.dict.ChainMap” and “collections.ChainMap”
         return self.toprepr(chainmap, level)
+    
+    def shortrepr(self, thing):
+        """ Return the “short” repr of a chainmap instance –
+            all whitespace will be condensed to single spaces
+            without newlines.
+        """
+        return WHITESPACE.sub(' ', self.repr(thing))
 
 reprizer = ChainRepr()
 cmrepr = reprizer.repr
+cmshortrepr = reprizer.shortrepr
 
 # CHAINMAP: a reimplementation
 
@@ -328,7 +336,7 @@ class ChainMap(collections.abc.MutableMapping,
     def mapcontaining(self, itx, default=NoDefault):
         from clu.predicates import finditem
         if default is NoDefault:
-            return finditem(itx, *self.maps) or self.__missing__(itx)
+            return finditem(itx, *self.maps) or { itx : self.__missing__(itx) }
         return finditem(itx, *self.maps, default=default)
     
     def flatten(self):
@@ -429,10 +437,17 @@ def merge(*dicts, **overrides):
 @export
 def asdict(thing):
     """ asdict(thing) → returns either thing, thing.__dict__, or dict(thing) as necessary """
-    from clu.predicates import haspyattr
+    from clu.predicates import haspyattr, or_none
     from clu.typology import ismapping
-    if isinstance(thing, dict):
-        return thing
+    from clu.typespace.namespace import isnamespace
+    if ischainmap(thing):
+        return merge_fast(*reversed(thing.maps))
+    if isnamespace(thing):
+        return dict(thing.__dict__)
+    if ismapping(thing):
+        return dict(thing)
+    if callable(or_none(thing, 'items')):
+        return dict(thing.items())
     if haspyattr(thing, 'dict'):
         return asdict(thing.__dict__)
     if hasattr(thing, '_asdict'):
@@ -441,10 +456,16 @@ def asdict(thing):
         return asdict(thing.to_dict())
     if hasattr(thing, 'dict'):
         return asdict(thing.dict)
-    if ismapping(thing):
-        return dict(thing)
+    if isinstance(thing, dict):
+        return thing
     return dict(thing)
 
+with exporter as export:
+    
+    export(reprizer,    name='reprizer')
+    export(cmshortrepr, name='cmshortrepr')
+    export(cmrepr,      name='cmrepr',          doc="Return the “core” repr for any descendant ChainMap type.")
+
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
 
@@ -455,7 +476,6 @@ def test():
     from clu.fs.filesystem import Directory
     from clu.predicates import try_items
     from clu.testing.utils import inline, format_environment
-    # from pprint import pprint
     import os
     
     stash = {}
@@ -491,7 +511,7 @@ def test():
     
     @inline
     def test_one():
-        """ Shallow clone membership check, slow flatten """
+        """ Shallow clone membership check """
         chain0 = ChainMap(dict_arbitrary(),
                                   fsdata(),
                              environment())
@@ -506,38 +526,13 @@ def test():
             # N.B. SLOW AS FUCK:
             assert key in chain0.flatten()
             
-            assert try_items(key, *chain0.maps, default=None) is not None
-            assert try_items(key, *chain1.maps, default=None) is not None
-            assert try_items(key, *chain0.maps, default=None) == try_items(key, *chain1.maps, default=None)
-            assert try_items(key, *chain0.maps, default=None) == chain0[key]
-            assert try_items(key, *chain0.maps, default=None) == chain1[key]
-    
-    @inline
-    def test_one_point_five():
-        """ Shallow clone membership check, fast flatten """
-        chain0 = ChainMap(dict_arbitrary(),
-                                  fsdata(),
-                             environment())
-        
-        chain1 = chain0.clone()
-        assert len(chain0) == len(chain1)
-        
-        for key in chain0.keys():
-            assert key in chain0
-            assert key in chain1
-            
-            # N.B. SLOW AS FUCK:
-            assert key in chain0.flatten()
-            
-            assert try_items(key, *chain0.maps, default=None) is not None
-            assert try_items(key, *chain1.maps, default=None) is not None
             assert try_items(key, *chain0.maps, default=None) == try_items(key, *chain1.maps, default=None)
             assert try_items(key, *chain0.maps, default=None) == chain0[key]
             assert try_items(key, *chain0.maps, default=None) == chain1[key]
     
     @inline
     def test_two():
-        """ Deep clone membership check, slow flatten """
+        """ Deep clone membership check """
         chain0 = ChainMap(dict_arbitrary(),
                                   fsdata(),
                              environment())
@@ -552,31 +547,6 @@ def test():
             # N.B. SLOW AS FUCK:
             assert key in chain0.flatten()
             
-            assert try_items(key, *chain0.maps, default=None) is not None
-            assert try_items(key, *chainX.maps, default=None) is not None
-            assert try_items(key, *chain0.maps, default=None) == try_items(key, *chainX.maps, default=None)
-            assert try_items(key, *chain0.maps, default=None) == chain0[key]
-            assert try_items(key, *chain0.maps, default=None) == chainX[key]
-    
-    @inline
-    def test_two_point_five():
-        """ Deep clone membership check, fast flatten """
-        chain0 = ChainMap(dict_arbitrary(),
-                                  fsdata(),
-                             environment())
-        
-        chainX = chain0.clone(deep=True)
-        assert len(chain0) == len(chainX)
-        
-        for key in chain0.keys():
-            assert key in chain0
-            assert key in chainX
-            
-            # N.B. SLOW AS FUCK:
-            assert key in chain0.flatten()
-            
-            assert try_items(key, *chain0.maps, default=None) is not None
-            assert try_items(key, *chainX.maps, default=None) is not None
             assert try_items(key, *chain0.maps, default=None) == try_items(key, *chainX.maps, default=None)
             assert try_items(key, *chain0.maps, default=None) == chain0[key]
             assert try_items(key, *chain0.maps, default=None) == chainX[key]
@@ -584,7 +554,7 @@ def test():
     @inline
     def test_three():
         """ Equality comparisons across the board """
-        from clu.config.defg import flatdict, Flat
+        from clu.config.keymap import flatdict, Flat
         
         chain0 = ChainMap(dict_arbitrary(),
                            Flat(flatdict()))
@@ -601,21 +571,11 @@ def test():
         print()
         print(repr(chain0))
         print()
-        
-        # print("REPR»CHAIN1:")
-        # print()
-        # print(repr(chain1))
-        # print()
-        
-        # print("REPR»CHAINX:")
-        # print()
-        # print(repr(chainX))
-        # print()
     
     @inline
     def test_four_experimental():
         """ Nested map source for ChainMap """
-        from clu.config.defg import nestedmaps
+        from clu.config.keymap import nestedmaps
         
         chainN = ChainMap(nestedmaps())
         
@@ -627,7 +587,7 @@ def test():
     @inline
     def test_five():
         """ Compatibility checks with “collections.ChainMap” """
-        from clu.config.defg import flatdict, Flat
+        from clu.config.keymap import flatdict, Flat
         
         chain0 = ChainMap(dict_arbitrary(), Flat(flatdict()))
         chainO = collections.ChainMap(dict_arbitrary(), Flat(flatdict()))
@@ -641,6 +601,10 @@ def test():
         
         assert chainZ == chain0
         assert chainZ == chainO
+        
+        repr_instance = ChainRepr()
+        
+        assert repr_instance.repr(chain0) == repr_instance.repr(chainO)
     
     @inline.diagnostic
     def restore_environment():
