@@ -4,10 +4,9 @@ from functools import wraps, lru_cache
 
 import collections.abc
 import clu.abstract
-import os
+import sys, os, re
+
 import pprint
-import re
-import sys
 import textwrap
 
 from clu.constants import consts
@@ -270,11 +269,11 @@ class InlineTester(collections.abc.Set,
             with watch.timer(label_timer):
                 out = function(*args, **kwargs)
             
-            # If we asked for it, we’ll get it:
-            if newline and verbose:
-                print()
-            
             if verbose:
+                # If we asked for it, we’ll get it:
+                if newline:
+                    print()
+                
                 # Get the reported timer value *before* closing out
                 # the root-level stopwatch timer:
                 timervals = item(watch._reported_values, label_timer,
@@ -538,27 +537,31 @@ def stdpout():
     # If we’ve been here before we don’t need to bother:
     if not getattr(pout, '__WTF_HAX__', False):
         
-        # Step one: pop off the old stderr-bound handler:
-        pout.stream.logger.handlers.pop()
+        try:
+            # Step one: pop off the old stderr-bound handler:
+            pout.stream.logger.handlers.pop()
+            
+            # Step two: set up a new logging StreamHandler:
+            loghandler = logging.StreamHandler(stream=sys.stdout)
+            loghandler.setFormatter(logging.Formatter('%(message)s'))
+            pout.stream.logger.addHandler(loghandler)
+            pout.stream.logger.propagate = False
+            
+            # Step three: instantiate a “pout.StderrStream” and root
+            # around with that shit to use `sys.stdout`:
+            streamy = pout.StderrStream()
+            streamy.logger = pout.stream.logger
+            streamy.logger.setLevel(logging.DEBUG)
+            streamy.logger.handlers[0].setStream(sys.stdout)
+            streamy.logger.handlers[0].set_name('stderr')
+            streamy.logger.handlers[0].setLevel(logging.DEBUG)
+            
+            # Step four DONT CROSS THE STREAMS WHATEVER YOU DO
+            stdpout.oldstreamy = pout.stream
+            pout.stream = streamy
         
-        # Step two: set up a new logging StreamHandler:
-        loghandler = logging.StreamHandler(stream=sys.stdout)
-        loghandler.setFormatter(logging.Formatter('%(message)s'))
-        pout.stream.logger.addHandler(loghandler)
-        pout.stream.logger.propagate = False
-        
-        # Step three: instantiate a “pout.StderrStream” and root
-        # around with that shit to use `sys.stdout`:
-        streamy = pout.StderrStream()
-        streamy.logger = pout.stream.logger
-        streamy.logger.setLevel(logging.DEBUG)
-        streamy.logger.handlers[0].setStream(sys.stdout)
-        streamy.logger.handlers[0].set_name('stderr')
-        streamy.logger.handlers[0].setLevel(logging.DEBUG)
-        
-        # Step four DONT CROSS THE STREAMS WHATEVER YOU DO
-        stdpout.oldstreamy = pout.stream
-        pout.stream = streamy
+        except AttributeError:
+            pass
         
         # Step five: doctor the “pout” module reflecting our change:
         pout.__WTF_HAX__ = True
@@ -608,7 +611,7 @@ def test():
         pypath.enhance(prefix0, prefix1)
         
         from yodogg.config import Env
-        from clu.config.defg import Environ
+        from clu.config.keymap import Environ
         
         env0 = Env()
         envy = Environ(appname=Env.appname)
@@ -627,8 +630,8 @@ def test():
     def test_two():
         """ Busywork, mark II. """
         # Fuck around with the CLU app’s environment overrides:
-        from clu.config.env import Env
-        from clu.config.defg import Environ
+        from clu.config.base import Env
+        from clu.config.keymap import Environ
         
         env0 = Env()
         envy = Environ(appname=Env.appname)
