@@ -7,11 +7,12 @@ import pytest
 class TestConfigKeyMaps(object):
     
     def test_nested_and_flat_KeyMaps(self):
-        from clu.config.defg import (Nested, KeyMapKeysView,
-                                             KeyMapItemsView,
-                                             KeyMapValuesView, NamespaceWalkerKeysView,
-                                                               NamespaceWalkerItemsView,
-                                                               NamespaceWalkerValuesView)
+        from clu.config.keymap import Nested
+        from clu.config.keymapview import (KeyMapKeysView,
+                                           KeyMapItemsView,
+                                           KeyMapValuesView, NamespaceWalkerKeysView,
+                                                             NamespaceWalkerItemsView,
+                                                             NamespaceWalkerValuesView)
         
         tree = {
             'yo'        : "dogg",
@@ -71,7 +72,8 @@ class TestConfigKeyMaps(object):
         assert renestified == nested
     
     def test_env_get_KeyMaps(self, environment, consts):
-        from clu.config.defg import Environ
+        from clu.config.keymap import Environ
+        
         env = Environ(environment=environment,
                           appname=consts.PROJECT_NAME)
         
@@ -98,7 +100,8 @@ class TestConfigKeyMaps(object):
         assert 'envtest1' not in env.namespaces()
     
     def test_env_set_KeyMaps(self, environment, consts):
-        from clu.config.defg import Environ
+        from clu.config.keymap import Environ
+        
         env = Environ(environment=environment,
                           appname=consts.PROJECT_NAME)
         
@@ -379,7 +382,8 @@ class TestConfig(object):
         assert "cannot import name" in str(exc.value)
     
     def test_env_get(self, environment):
-        from clu.config.env import Env
+        from clu.config.base import Env
+        
         env = Env()
         
         try:
@@ -405,7 +409,8 @@ class TestConfig(object):
         assert 'envtest1' not in env.namespaces()
     
     def test_env_set(self, environment):
-        from clu.config.env import Env
+        from clu.config.base import Env
+        
         env = Env()
         
         try:
